@@ -1,6 +1,7 @@
 import LibHanger.Library.uwLogger as Logger
 from selenium.common.exceptions import TimeoutException, WebDriverException
 from selenium import webdriver
+from selenium.webdriver.common.desired_capabilities import DesiredCapabilities
 from selenium.webdriver.chrome.options import Options as chromeOptions
 from selenium.webdriver.firefox.options import Options as firefoxOptions
 from LibHanger.Library.uwGlobals import *
@@ -87,15 +88,26 @@ class browserContainer:
             Logger.logging.info('get webdriver - start')
             Logger.logging.info(self.config.chrome.WebDriverLogPath)
             try:
+                # ページ読み込み待ち処理の無効/有効を設定する
+                desired = DesiredCapabilities().CHROME
+                desired['pageLoadStrategy'] = self.config.PageLoadStrategy
+
+                # WebDriver生成
                 if self.config.chrome.WebDriverLogPath == '':
-                    self.wDriver = webdriver.Chrome(executable_path=webDriverPath, options=options)
+                    self.wDriver = webdriver.Chrome(executable_path=webDriverPath, 
+                                                    options=options, 
+                                                    desired_capabilities=desired)
                 else:
-                    self.wDriver = webdriver.Chrome(executable_path=webDriverPath, service_log_path=self.config.chrome.WebDriverLogPath, options=options)
-                Logger.logging.info('get webdriver - end')
+                    self.wDriver = webdriver.Chrome(executable_path=webDriverPath, 
+                                                    service_log_path=self.config.chrome.WebDriverLogPath, 
+                                                    options=options,
+                                                    desired_capabilities=desired)
             except TimeoutException as e:
-                Logger.logging.info("Selenium Exception: {0} Message: {1}".format("TimeoutException", str(e)))
+                Logger.logging.error("Selenium Exception: {0} Message: {1}".format("TimeoutException", str(e)))
             except WebDriverException as e:
-                Logger.logging.info("Selenium Exception: {0} Message: {1}".format("WebDriverException", str(e)))
+                Logger.logging.error("Selenium Exception: {0} Message: {1}".format("WebDriverException", str(e)))
+            finally:
+                Logger.logging.info('get webdriver - end')
             return self.wDriver 
         
     class firefox(baseWebBrowserController):
@@ -156,10 +168,11 @@ class browserContainer:
                     self.wDriver = webdriver.Firefox(executable_path=webDriverPath, options=options)
                 else:
                     self.wDriver = webdriver.Firefox(executable_path=webDriverPath, log_path=self.config.firefox.WebDriverLogPath, options=options)            
-                Logger.logging.info('get webdriver - end')
             except TimeoutException as e:
-                Logger.logging.info("Selenium Exception: {0} Message: {1}".format("TimeoutException", str(e)))
+                Logger.logging.error("Selenium Exception: {0} Message: {1}".format("TimeoutException", str(e)))
             except WebDriverException as e:
-                Logger.logging.info("Selenium Exception: {0} Message: {1}".format("WebDriverException", str(e)))
+                Logger.logging.error("Selenium Exception: {0} Message: {1}".format("WebDriverException", str(e)))
+            finally:
+                Logger.logging.info('get webdriver - end') 
             return self.wDriver 
         
\ No newline at end of file
